<?php
namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\SM\Service\Sm00006000ComposicaoServicosService as ComposicaoService;

class Sm00006000ComposicaoServicosController extends SMCrud
{
    protected $dataSourceName = "fct_compservico_widget";
    protected $composicaoService;
    
    public function __construct ($crudService, $environment, ComposicaoService $composicaoService) {
        parent::__construct($crudService, $environment);
        $this->composicaoService = $composicaoService;
    }
    
    public function save(Request $request, Response $response) {
        $request->setParameter('dbname', 'fct_compservico_widget');
        parent::save($request, $response);
        //tentar salvar os dados dos filhos
        try{
            $row = $request->getDataSet()->getRows();
            $row = $row[0];
            $idAtivo        = $row["IDATIVO"];
            $nrcompservico  = $row["NRCOMPSERVICO"];
            $operador       = $this->environment->getCdOperador();
            $nrorg          = $this->environment->getNrorg();
            $cdCentCust     = $row["CDCENTCUST"];
            $this->composicaoService->replicarAlteracaoIdAtivo($idAtivo, $nrcompservico, $operador, $nrorg, $cdCentCust);
        }catch(\Exception $e){
            throw $e;
        }
        $response->addDataSet(new DataSet("columnsToReturn", $this->crudService->getColumnsToReturn()));
    }
    
    /**
     * Sincroniza os elementos da composição de acordo com a tela de elementos.
     * 
     * @param Request $request
     * @param Response $response
     */
    public function sincronizarComposicao(Request $request, Response $response) {
        $row = $request->getRow();
        $nrcompservico = $row["NRCOMPSERVICO"];
        $nrorg         = $row["NRORG"];
        
        $this->composicaoService->executarProcedureFctSincronizarComposicao($nrcompservico, $nrorg);
    }
    
    /**
     * Exclui a composição e seus filhos.
     * 
     * @param Request $request
     * @param Response $response
     */
    public function delete(Request $request, Response $response) {
        $row = $request->getRow();
        $nrcompservico = $row["NRCOMPSERVICO"];
        $nrorg         = $row["NRORG"];
        
        $this->composicaoService->excluirComposicaoEmCascata($nrcompservico, $nrorg);
        $response->addMessage(new Response\Message("Registro excluído com sucesso."));
    }
    
    
    public function find(Request\Filter $request, Response $response) {
    
        $request->setParameter('dbname', 'fct_compservico_widget');
        parent::find($request, $response);
    
    }
    /**
     * Manda replicar as informações do IDATIVO para todos os filhos 
     * da composição de serviço alterada.
    **/
    public function replicarAlteracaoIdAtivo(Request\Row $request, Response $response){
        try {
            $row = $request->getRow();
            $idAtivo        = $row["IDATIVO"];
            $nrcompservico  = $row["NRCOMPSERVICO"];
            $operador       =  $this->environment->getCdOperador();
            $nrorg          =  $this->environment->getNrorg();
            $cdCentCust     = $row["CDCENTCUST"];
            $this->composicaoService->replicarAlteracaoIdAtivo($idAtivo, $nrcompservico, $operador, $nrorg, $cdCentCust);
        } catch(\Exception $e) {
            $response->SetError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
}

?>